﻿from django.shortcuts import get_object_or_404, render
from electronics.models import Component, TypeComponent


# ====================================================
# Описание работы классов и методов исходника на:
# https://www.interestprograms.ru
# Исходные коды программ и игр
# Автор исходных кодов Клочков Павел
# ====================================================

# ===== Контроллеры =====


# Контроллеры для главной страницы
def index(request):
    text = "Здравствуйте! Рады вас видеть в магазине Электроники!"
    context = {"content": text, "title": text}
    return render(request, "electronics/index.html", context)


def catalog(request):
    tc = TypeComponent.objects.all()
    context = {"list_typecomponent": tc, "title": "Каталог", "color": "black"}
    return render(request, "electronics/catalog.html", context)


def catalog_section(request, type_id):
    # Проверка существования элемента
    tc = get_object_or_404(TypeComponent, id=type_id)
    # Получение списка объектов по указанному ключу:
    list_components = Component.objects.all().filter(type_foreignkey=tc.id)
    context = {
        # Отправка в html шаблон кортежа из индексов и значений элементов
        # класс enumerate дает возможность получать
        # индексы и значения элементов списка
        "list_typecomponent": enumerate(list_components, 1),
        "title": tc.name,
        "color": "black",
    }
    return render(request, "electronics/catalog_section.html", context)


def component(request, component_id):
    # Проверка существования элемента
    component = get_object_or_404(Component, id=component_id)
    # Получение объекта по первичному ключу:
    component = Component.objects.get(id=component.id)
    context = {
        # Отправка в html шаблон кортежа из индексов и значений элементов
        "component": component,
        "title": component.name,
        "color": "black",
    }
    return render(request, "electronics/page_component.html", context)


def contacts(request):
    context = {
        "title": "Контакты",
    }
    # render - функция быстрого доступа фреймворка Django,
    # возвращает  HttpResponse
    return render(request, "electronics/contacts.html", context)


# Функция-контроллер, переопределяющая вызов шаблона при ошибке 404
def error404(request, exception):
    context = {"title": "Страница не найдена!"}
    return render(request, "electronics/shared/error404.html", context)


# ===== /Контроллеры =====

# ===== Вспомогательные функции =====


# Вспомогательная функция, группирующая одинаковый код для некоторых контроллеров
#def func(request, text="", color="black"):
#    context = {"content": text, "title": text, "color": color}
#    return render(request, "electronics/page.html", context)


# ===== /Вспомогательные функции =====
